@@ -2,7 +2,6 @@
 #'
 #' @description A DESCRIPTION OF THE PACKAGE
 #'
-#' @docType package
 #' @name rbioacc-package
 #' @aliases rbioacc
 #' @useDynLib rbioacc, .registration = TRUE
@@ -14,4 +13,4 @@
 #' @references
 #' Stan Development Team (NA). RStan: the R interface to Stan. R package version NA. https://mc-stan.org
 #'
-NULL
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
