@@ -1,6 +1,6 @@
 test_that(".interpolate_Inf", {
-  v1 = c(Inf, Inf, 3, Inf, 5, Inf, Inf, 4, Inf, Inf)
-  t1 = 1:length(v1)
+  v1 <- c(Inf, Inf, 3, Inf, 5, Inf, Inf, 4, Inf, Inf)
+  t1 <- 1:length(v1)
   expect_true(all(rbioacc:::.interpolate_Inf(v1, t1) == c(0,0,3,4,5,14/3, 13/3,4,0,0) ))
 })
 
