@@ -7,11 +7,11 @@ test_that("modelData outputs", {
   expect_error(modelData(Male_Gammarus_seanine_growth, time_accumulation = 1.417), NA)
   
   data("Male_Gammarus_Merged")
-  df_1 = with(Male_Gammarus_Merged, Male_Gammarus_Merged[expw == 7.08021e-05,])
+  df_1 <- with(Male_Gammarus_Merged, Male_Gammarus_Merged[expw == 7.08021e-05,])
   expect_error(modelData(df_1, time_accumulation = 4), NA)
   
   data("Oncorhynchus_two")
-  df_2 = with(Oncorhynchus_two, Oncorhynchus_two[replicate == 1,])
+  df_2 <- with(Oncorhynchus_two, Oncorhynchus_two[replicate == 1,])
   expect_error(modelData(df_2, time_accumulation = 49), NA)
   
   data("Chironomus_benzoapyrene")
@@ -21,7 +21,7 @@ test_that("modelData outputs", {
 
 test_that("TEST .check_modelData_object", {
   data("Male_Gammarus_Single")
-  test_object = Male_Gammarus_Single
+  test_object <- Male_Gammarus_Single
   expect_null(rbioacc:::.check_modelData_object(test_object))
 })
 
